.. title:: Home

.. raw:: html

    <div class="banner">
        <img src="_static/verde-logo.png" alt="Verde" width="300px">
        <h2>Processing and gridding spatial data</h2>
        <p>A part of the <a href="https://www.fatiando.org/">Fatiando a Terra</a> project.</p>
        <a href="/gallery"><img src="_static/banner.png" alt="A sample of what Verde can do"></a>
    </div>

.. include:: ../README.rst
    :start-after: placeholder-for-doc-index


.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Getting Started

    tutorials/overview.rst
    install.rst
    citing.rst
    gallery/index.rst

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: User Guide

    sample_data/index.rst
    tutorials/grid_coordinates.rst
    tutorials/trends.rst
    tutorials/decimation.rst
    tutorials/projections.rst
    tutorials/chain.rst
    tutorials/model_evaluation.rst
    tutorials/model_selection.rst
    tutorials/weights.rst
    tutorials/vectors.rst

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Reference documentation

    api/index.rst
    changes.rst
    references.rst
